@@ -61,11 +61,21 @@ def get_dbagent_client(cfg_dir):
     dbagent_client = klass(server_endpoint, config)
     return dbagent_client
 
+def get_path(path):
+    if path is None:
+        return None
+    path = path.strip()
+    if len(path) == 0:
+        return None
+    return os.path.expandvars(path)
+
 def generate_execute_command(application, args):
     cmd = ""
-    if application['venv_dir']:
+
+    venv_dir = get_path(application.get('venv_dir'))
+    if venv_dir is not None:
         # if the application has venv_dir, we need to activate virtual environment
-        cmd += f"source {os.path.join(application['venv_dir'], 'bin', 'activate')}\n"
+        cmd += f"source {os.path.join(venv_dir, 'bin', 'activate')}\n"
 
     entry = application['entry']
     if entry.endswith(".py"):
@@ -160,13 +170,7 @@ def main():
         logger.info("main: exit")
         sys.exit(2)
 
-    home_dir = application.get("home_dir")
-    if home_dir is not None:
-        home_dir = home_dir.strip()
-        if len(home_dir) == 0:
-            home_dir = None
-        else:
-            home_dir = os.path.expandvars(home_dir)
+    home_dir = get_path(application.get("home_dir"))
     try:
         child_process = subprocess.Popen(
             cmd,
